# superdirtpy
superdirtpy is a python library for algorithmic composition working with [SuperDirt](https://github.com/musikinformatik/SuperDirt).

## prerequisite
Install TidalCycles/SuperDirt.

## examples
- [examples](./examples/)
- https://github.com/inaba1115/algorithmic-composition-playground

## plugins
- https://github.com/inaba1115/batch-midi
